@@ -9,7 +9,9 @@
 
 /* external Fortran 90 subroutine */
 #define Del2Apply del2apply_
+EXTERN_C_BEGIN
 extern void Del2Apply(int*,double*,const double*,double*);
+EXTERN_C_END
 
 /* user data structure and routines 
  * defining the matrix-free operator */
@@ -19,8 +21,6 @@ typedef struct {
   PetscScalar *F;
 } Del2Mat;
 
-#undef  __FUNCT__  
-#define __FUNCT__ "Del2Mat_mult"
 /* y <- A * x */
 PetscErrorCode Del2Mat_mult(Mat A, Vec x, Vec y) 
 {
@@ -40,8 +40,7 @@ PetscErrorCode Del2Mat_mult(Mat A, Vec x, Vec y)
   ierr = VecRestoreArray(y,&yy);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
-#undef  __FUNCT__  
-#define __FUNCT__ "Del2Mat_diag"
+
 /*D_i <- A_ii */
 PetscErrorCode Del2Mat_diag(Mat A, Vec D) 
 {
