@@ -73,28 +73,25 @@ def setup_unittest(options):
     _WritelnDecorator.writeln = writeln
 
 def import_package(options, pkgname):
-    args=[sys.argv[0],
-          '-malloc',
-          '-malloc_debug',
-          '-malloc_dump',
-          '-log_summary',
-          ]
-    if not options.summary:
-        del args[-1]
+    args = [
+        sys.argv[0],
+        '-malloc',
+        '-malloc_debug',
+        '-malloc_dump',
+    ]
+    if options.summary:
+        args.append('-log_view')
     package = __import__(pkgname)
     package.init(args, arch=options.arch)
     return package
 
 def getprocessorinfo():
+    from platform import uname
     from petsc4py.PETSc import COMM_WORLD
     rank = COMM_WORLD.getRank()
-    name =  os.uname()[1]
+    name = uname()[1]
     return (rank, name)
 
-def getpythoninfo():
-    x, y = sys.version_info[:2]
-    return ("Python %d.%d (%s)" % (x, y, sys.executable))
-
 def getlibraryinfo():
     from petsc4py import PETSc
     (major, minor, micro) = PETSc.Sys.getVersion()
@@ -105,6 +102,10 @@ def getlibraryinfo():
     return ("PETSc %d.%d.%d %s (conf: '%s')"
             % (major, minor, micro, release, arch) )
     
+def getpythoninfo():
+    x, y = sys.version_info[:2]
+    return ("Python %d.%d (%s)" % (x, y, sys.executable))
+
 def getpackageinfo(pkg):
     return ("%s %s (%s)" % (pkg.__name__,
                             pkg.__version__,
@@ -156,27 +157,42 @@ def load_tests(options, args):
             testsuite.addTests(cases)
     return testsuite
 
-def run_tests(options, testsuite):
-    runner = unittest.TextTestRunner(verbosity=options.verbose)
-    runner.failfast = options.failfast
+def run_tests(options, testsuite, runner=None):
+    if runner is None:
+        runner = unittest.TextTestRunner(verbosity=options.verbose)
+        runner.failfast = options.failfast
     result = runner.run(testsuite)
     return result.wasSuccessful()
 
-def run_tests_leaks(options, testsuite):
+def test_refleaks(options, args):
     from sys import gettotalrefcount
     from gc import collect
+    from copy import deepcopy
+    testsuite = load_tests(options, args)
+    class EmptyIO(object):
+        def write(self, *args):
+            pass
+    runner = unittest.TextTestRunner(stream=EmptyIO(), verbosity=0)
     rank, name = getprocessorinfo()
     r1 = r2 = 0
     repeats = options.repeats
     while repeats:
-        repeats -= 1
         collect()
         r1 = gettotalrefcount()
-        run_tests(options, testsuite)
+        run_tests(options, deepcopy(testsuite), runner)
         collect()
         r2 = gettotalrefcount()
-        writeln('[%d@%s] refleaks:  (%d - %d) --> %d'
-                % (rank, name, r2, r1, r2-r1))
+        leaks = r2-r1
+        if leaks and repeats < options.repeats:
+            writeln('[%d@%s] refleaks:  (%d - %d) --> %d'
+                    % (rank, name, r2, r1, leaks))
+        repeats -= 1
+
+def abort(code=1):
+    os.abort()
+
+def shutdown(success):
+    pass
 
 def main(args=None):
     pkgname = 'petsc4py'
@@ -188,8 +204,10 @@ def main(args=None):
     print_banner(options, package)
     testsuite = load_tests(options, args)
     success = run_tests(options, testsuite)
+    if not success and options.failfast: abort()
     if success and hasattr(sys, 'gettotalrefcount'):
-        run_tests_leaks(options, testsuite)
+        test_refleaks(options, args)
+    shutdown(success)
     return not success
 
 if __name__ == '__main__':
