@@ -104,7 +104,8 @@ class BaseTestTSNonlinearRHS(BaseTestTSNonlinear):
         T = T0 + nT*dT
         ts.setTime(T0)
         ts.setTimeStep(dT)
-        ts.setDuration(T, nT)
+        ts.setMaxTime(T)
+        ts.setMaxSteps(nT)
         ts.setFromOptions()
         u[0], u[1], u[2] = 1, 2, 3
         ts.solve(u)
@@ -143,7 +144,8 @@ class BaseTestTSNonlinearRHS(BaseTestTSNonlinear):
         T = T0 + nT*dT
         ts.setTime(T0)
         ts.setTimeStep(dT)
-        ts.setDuration(T, nT)
+        ts.setMaxTime(T)
+        ts.setMaxSteps(nT)
         ts.setFromOptions()
         u[0], u[1], u[2] = 1, 2, 3
 
@@ -155,8 +157,10 @@ class BaseTestTSNonlinearRHS(BaseTestTSNonlinear):
 
     def testResetAndSolveRHS(self):
         self.ts.reset()
+        self.ts.setStepNumber(0)
         self.testSolveRHS()
         self.ts.reset()
+        self.ts.setStepNumber(0)
         self.testSolveRHS()
         self.ts.reset()
 
@@ -186,7 +190,8 @@ class BaseTestTSNonlinearI(BaseTestTSNonlinear):
         T = T0 + nT*dT
         ts.setTime(T0)
         ts.setTimeStep(dT)
-        ts.setDuration(T, nT)
+        ts.setMaxTime(T)
+        ts.setMaxSteps(nT)
         ts.setFromOptions()
         u[0], u[1], u[2] = 1, 2, 3
         ts.solve(u)
@@ -226,7 +231,8 @@ class BaseTestTSNonlinearI(BaseTestTSNonlinear):
         T = T0 + nT*dT
         ts.setTime(T0)
         ts.setTimeStep(dT)
-        ts.setDuration(T, nT)
+        ts.setMaxTime(T)
+        ts.setMaxSteps(nT)
         ts.setFromOptions()
         u[0], u[1], u[2] = 1, 2, 3
 
@@ -238,8 +244,10 @@ class BaseTestTSNonlinearI(BaseTestTSNonlinear):
 
     def testResetAndSolveI(self):
         self.ts.reset()
+        self.ts.setStepNumber(0)
         self.testSolveI()
         self.ts.reset()
+        self.ts.setStepNumber(0)
         self.testSolveI()
         self.ts.reset()
 
